@@ -115,6 +115,11 @@ class Gps {
    */
   void resetSerial(std::string port);
 
+  /**
+   * @brief Send rtcm correction message.
+  */
+  bool sendRtcm(const std::vector<uint8_t> &message);
+
   /**
    * @brief Closes the I/O port, and initiates save on shutdown procedure
    * if enabled.
