@@ -1809,9 +1809,14 @@ void TimProduct::initializeRosDiagnostics() {
   updater->force_update();
 }
 
+void rtcmCallback(const rtcm_msgs::Message::ConstPtr &msg) {
+  gps.sendRtcm(msg->message);
+}
+
 int main(int argc, char** argv) {
   ros::init(argc, argv, "ublox_gps");
   nh.reset(new ros::NodeHandle("~"));
+  ros::Subscriber subRtcm = nh->subscribe("/rtcm", 10, rtcmCallback);
   nh->param("debug", ublox_gps::debug, 1);
   if(ublox_gps::debug) {
     if (ros::console::set_logger_level(ROSCONSOLE_DEFAULT_NAME,
